@@ -1,30 +1,28 @@
-use std::{collections::HashMap, rc::Rc, thread, time::Instant};
-
-use dbfile::{DBfile};
-use dbfile_derive::{DBfile, dbnote};
-use lazy_static::__Deref;
-use requests2::{Cache, Headers, Requests};
-use select::predicate::Name;
+use std::{collections::HashMap, ops::Deref, rc::Rc, thread, time::Instant};
 
+use requests2::{
+    dbfile::DBfile,
+    dbfile_derive::{dbnote, DBfile},
+    select::predicate::Name, Cache, Headers, Requests,
+};
 
 #[derive(DBfile)]
-#[dbnote(table_name = "b1", driver = "postgres", primary_key="href")]
+#[dbnote(table_name = "b339", driver = "postgres", primary_key = "href")]
 struct Item<'a> {
     book_name: &'a str,
     href: String,
     img: String,
     isbn: String,
-    price: f32
+    price: f32,
 }
 
-
 fn create_table() {
     let by_data = Item {
         book_name: "test",
         href: "".to_string(),
         img: "".to_string(),
         isbn: "".to_string(),
-        price: 6.5
+        price: 6.5,
     };
     by_data.create_table();
 }
@@ -37,8 +35,7 @@ fn main() {
 fn run() {
     let mut urls = Vec::new();
     let now = Instant::now();
-    let max_page = 50;
-
+    let max_page = 30;
 
     for p in 1..(max_page + 1) {
         let url = format!("https://book.kongfz.com/Cxianzhuang/cat_8001w{}/", &p);
@@ -48,7 +45,7 @@ fn run() {
     while urls.len() > 0 {
         let mut batch_urls = Vec::new();
 
-        for _ in 0..30 {
+        for _ in 0..10 {
             if urls.len() > 0 {
                 batch_urls.push(urls.remove(0));
             }
@@ -99,7 +96,6 @@ pub fn crawl_kongfz_by_page(page: i32, url: String) {
                             .to_string(),
                     );
 
-                    println!("price {:?}", price);
                     let mut _header = false;
                     if idx == 0 && page == 1 {
                         _header = true
