@@ -1,8 +1,9 @@
-use dbfile::{DBStore};
-use dbfile_derive::DBfile;
+use dbfile::{DBfile};
+use dbfile_derive::{DBfile, dbnote};
 
 
 #[derive(DBfile)]
+#[dbnote(table_name = "test1.csv")]
 struct Person<'a>{
     name: &'a str,
     age: u32,
@@ -25,7 +26,8 @@ pub fn run_write_csv() {
         age: 33
     };
     
-    DBStore::to_csv(vec![p1, p2], "D:/test.csv", "a", true);
-    DBStore::to_csv(vec![p3], "D:/test.csv", "a", false);
-
+    p1.write_csv_head();
+    p1.to_csv("a");
+    p2.to_csv("a");
+    p3.to_csv("a");
 }
\ No newline at end of file
