@@ -4,7 +4,7 @@ use requests2::{Requests, Headers, Cache, Store};
     fn test_find_target_href() {
         let data = Cache::new();
         let client = Requests::new(&data);
-        let mut rq = client.connect("https://www.qq.com", Headers::Default);
+        let rq = client.connect("https://www.qq.com", Headers::Default);
         rq.parser(|p| {
             p.find_all("a", |n| {
                 n.attr("href").map_or(false, |x| x.starts_with("http:")) 
